@@ -3,6 +3,7 @@ use warnings;
 
 package TestAppDoubleAutoBug;
 
+use TestLogger;
 use Catalyst qw/
     Test::Errors
     Test::Headers
@@ -13,6 +14,8 @@ our $VERSION = '0.01';
 
 __PACKAGE__->config( name => 'TestAppDoubleAutoBug', root => '/some/dir' );
 
+__PACKAGE__->log(TestLogger->new);
+
 __PACKAGE__->setup;
 
 sub execute {
@@ -44,3 +47,6 @@ sub execute {
 
     return $c->SUPER::execute(@_);
 }
+
+1;
+
